#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    MonitoringState,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_asg_interface():
    return Dictionary(
        elements=[
            ('state_not_full_duplex',
             MonitoringState(
                 default_value=2,
                 title=_('State if not Full duplex'),
                 help=_('Monitoring state if interface not in Full duplex state'),
             )),
            ('state_not_up_up',
             MonitoringState(
                 default_value=2,
                 title=_('State if not Up/Up'),
                 help=_('Monitoring state if interface not in Up/Up state'),
             )),
            ('state_speed_changed',
             MonitoringState(
                 default_value=1,
                 title=_('State if speed changed'),
                 help=_('Monitoring state if interface is differs from discovery time'),
             )),
            ('asgNetIfSpeed', TextAscii()),  # added by plugin discovery function
        ],
        hidden_keys=['asgNetIfSpeed']
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='checkpoint_asg_interface',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_asg_interface,
        title=lambda: _('Check Point ASG Interface'),
        item_spec=lambda: TextAscii(title=_('Interface name'), ),
    ))
